@@ -21,7 +21,7 @@ class PngCm(Depot):
         }
         response = requests.post('https://png.cm/application/upload.php', data=data, files=files)
         if response.status_code != 200:
-            return self._set_error('upload fail')
+            return self._set_error(f'upload fail. code: {response.status_code}. content: {response.text}')
         data = response.json()
         if data.get('code') != 200 or not data.get('url'):
             return self._set_error(response.text)
